==> aws-cdk-scala_2.12-0.18.0-sources.jar: io/burkard/cdk/services/ec2/cfnLaunchTemplate/NetworkInterfaceProperty.scala <==
package io.burkard.cdk.services.ec2.cfnLaunchTemplate

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object NetworkInterfaceProperty {

  def apply(
    interfaceType: Option[String] = None,
    associateCarrierIpAddress: Option[Boolean] = None,
    ipv6PrefixCount: Option[Number] = None,
    description: Option[String] = None,
    ipv4PrefixCount: Option[Number] = None,
    ipv6Prefixes: Option[List[_]] = None,
    subnetId: Option[String] = None,
    groups: Option[List[String]] = None,
    privateIpAddresses: Option[List[_]] = None,
    deviceIndex: Option[Number] = None,
    associatePublicIpAddress: Option[Boolean] = None,
    networkCardIndex: Option[Number] = None,
    ipv6Addresses: Option[List[_]] = None,
    ipv6AddressCount: Option[Number] = None,
    ipv4Prefixes: Option[List[_]] = None,
    deleteOnTermination: Option[Boolean] = None,
    secondaryPrivateIpAddressCount: Option[Number] = None,
    privateIpAddress: Option[String] = None,
    networkInterfaceId: Option[String] = None
  ): software.amazon.awscdk.services.ec2.CfnLaunchTemplate.NetworkInterfaceProperty =
    (new software.amazon.awscdk.services.ec2.CfnLaunchTemplate.NetworkInterfaceProperty.Builder)
      .interfaceType(interfaceType.orNull)
      .associateCarrierIpAddress(associateCarrierIpAddress.map(Boolean.box).orNull)
      .ipv6PrefixCount(ipv6PrefixCount.orNull)
      .description(description.orNull)
      .ipv4PrefixCount(ipv4PrefixCount.orNull)
      .ipv6Prefixes(ipv6Prefixes.map(_.asJava).orNull)
      .subnetId(subnetId.orNull)
      .groups(groups.map(_.asJava).orNull)
      .privateIpAddresses(privateIpAddresses.map(_.asJava).orNull)
      .deviceIndex(deviceIndex.orNull)
      .associatePublicIpAddress(associatePublicIpAddress.map(Boolean.box).orNull)
      .networkCardIndex(networkCardIndex.orNull)
      .ipv6Addresses(ipv6Addresses.map(_.asJava).orNull)
      .ipv6AddressCount(ipv6AddressCount.orNull)
      .ipv4Prefixes(ipv4Prefixes.map(_.asJava).orNull)
      .deleteOnTermination(deleteOnTermination.map(Boolean.box).orNull)
      .secondaryPrivateIpAddressCount(secondaryPrivateIpAddressCount.orNull)
      .privateIpAddress(privateIpAddress.orNull)
      .networkInterfaceId(networkInterfaceId.orNull)
      .build()
}

==> aws-cdk-scala_2.13-0.9.0-sources.jar: io/burkard/cdk/services/ec2/cfnLaunchTemplate/NetworkInterfaceProperty.scala <==
package io.burkard.cdk.services.ec2.cfnLaunchTemplate

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object NetworkInterfaceProperty {

  def apply(
    interfaceType: Option[String] = None,
    associateCarrierIpAddress: Option[Boolean] = None,
    description: Option[String] = None,
    subnetId: Option[String] = None,
    groups: Option[List[String]] = None,
    privateIpAddresses: Option[List[_]] = None,
    deviceIndex: Option[Number] = None,
    associatePublicIpAddress: Option[Boolean] = None,
    networkCardIndex: Option[Number] = None,
    ipv6Addresses: Option[List[_]] = None,
    ipv6AddressCount: Option[Number] = None,
    deleteOnTermination: Option[Boolean] = None,
    secondaryPrivateIpAddressCount: Option[Number] = None,
    privateIpAddress: Option[String] = None,
    networkInterfaceId: Option[String] = None
  ): software.amazon.awscdk.services.ec2.CfnLaunchTemplate.NetworkInterfaceProperty =
    (new software.amazon.awscdk.services.ec2.CfnLaunchTemplate.NetworkInterfaceProperty.Builder)
      .interfaceType(interfaceType.orNull)
      .associateCarrierIpAddress(associateCarrierIpAddress.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .description(description.orNull)
      .subnetId(subnetId.orNull)
      .groups(groups.map(_.asJava).orNull)
      .privateIpAddresses(privateIpAddresses.map(_.asJava).orNull)
      .deviceIndex(deviceIndex.orNull)
      .associatePublicIpAddress(associatePublicIpAddress.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .networkCardIndex(networkCardIndex.orNull)
      .ipv6Addresses(ipv6Addresses.map(_.asJava).orNull)
      .ipv6AddressCount(ipv6AddressCount.orNull)
      .deleteOnTermination(deleteOnTermination.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .secondaryPrivateIpAddressCount(secondaryPrivateIpAddressCount.orNull)
      .privateIpAddress(privateIpAddress.orNull)
      .networkInterfaceId(networkInterfaceId.orNull)
      .build()
}
